==> qtjambi-debuginfo-macos-5.15.17.jar: sources/QtJambiGui/QIconDragEvent_shell.cpp <==
#include "QIconDragEvent_shell.h"
#include <QtJambi/Cast>

void deleter_QIconDragEvent(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QIconDragEvent")
    QIconDragEvent *_ptr = reinterpret_cast<QIconDragEvent *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QIconDragEvent_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QIconDragEvent_shell) ); }

jmethodID QIconDragEvent_shell::__shell_javaMethod(int pos) const { return QIconDragEvent_shell::__shell()->javaMethod(typeid(QIconDragEvent), pos); }

// emitting (writeShellConstructor)
QIconDragEvent_shell::QIconDragEvent_shell()
    : QIconDragEvent()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QIconDragEvent::QIconDragEvent_shell()", QIconDragEvent_shell::__shell())
    QIconDragEvent_shell::__shell()->constructed(typeid(QIconDragEvent));
}

// emitting (writeShellDestructor)
QIconDragEvent_shell::~QIconDragEvent_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QIconDragEvent::~QIconDragEvent()", QIconDragEvent_shell::__shell())
    QIconDragEvent_shell::__shell()->destructed(typeid(QIconDragEvent));
}

void QIconDragEvent_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QIconDragEvent_shell*>(ptr)->QIconDragEvent_shell::__shell()->tryDeleteShell(typeid(QIconDragEvent));
}

// emitting Virtual overrides (virtualFunctions)
// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
// emitting (writeConstructors)
// new QIconDragEvent()
void __qt_construct_QIconDragEvent_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QIconDragEvent()")
    Q_UNUSED(__java_arguments)
    QIconDragEvent *__qt_this = new(__qtjambi_ptr) QIconDragEvent_shell();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// destruct QIconDragEvent_shell
void __qt_destruct_QIconDragEvent(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QIconDragEvent")
    reinterpret_cast<QIconDragEvent_shell*>(ptr)->~QIconDragEvent_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QIconDragEvent::QIconDragEvent()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QIconDragEvent_initialize_1native__Lio_qt_gui_QIconDragEvent_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QIconDragEvent::QIconDragEvent()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QIconDragEvent_0, sizeof(QIconDragEvent_shell), typeid(QIconDragEvent), true, &deleter_QIconDragEvent, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QIconDragEvent_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QIconDragEvent *__qt_this = QtJambiAPI::objectFromNativeId<QIconDragEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QIconDragEvent(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QIconDragEvent>("QIconDragEvent", "io/qt/gui/QIconDragEvent");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QIconDragEvent, {
        ConstructorInfo(&__qt_construct_QIconDragEvent_0, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QIconDragEvent);
    registerMetaType<QIconDragEvent>("QIconDragEvent");
    registerSizeOfShell(typeId, sizeof(QIconDragEvent_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerDefaultPolymorphyHandler<QEvent, QIconDragEvent>();
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-debuginfo-macos-5.15.19.jar: sources/QtJambiGui/QIconDragEvent_shell.cpp <==
#include "QIconDragEvent_shell.h"
#include <QtJambi/Cast>

void deleter_QIconDragEvent(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QIconDragEvent")
    QIconDragEvent *_ptr = reinterpret_cast<QIconDragEvent *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QIconDragEvent_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QIconDragEvent_shell) ); }

jmethodID QIconDragEvent_shell::__shell_javaMethod(int pos) const { return QIconDragEvent_shell::__shell()->javaMethod(typeid(QIconDragEvent), pos); }

// emitting (writeShellConstructor)
QIconDragEvent_shell::QIconDragEvent_shell()
    : QIconDragEvent()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QIconDragEvent::QIconDragEvent_shell()", QIconDragEvent_shell::__shell())
    QIconDragEvent_shell::__shell()->constructed(typeid(QIconDragEvent));
}

QIconDragEvent_shell::QIconDragEvent_shell(const QIconDragEvent& other0)
    : QIconDragEvent(other0)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QIconDragEvent::QIconDragEvent_shell(const QIconDragEvent& other0)", QIconDragEvent_shell::__shell())
    QIconDragEvent_shell::__shell()->constructed(typeid(QIconDragEvent));
}

// emitting (writeShellDestructor)
QIconDragEvent_shell::~QIconDragEvent_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QIconDragEvent::~QIconDragEvent()", QIconDragEvent_shell::__shell())
    QIconDragEvent_shell::__shell()->destructed(typeid(QIconDragEvent));
}

void QIconDragEvent_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QIconDragEvent_shell*>(ptr)->QIconDragEvent_shell::__shell()->tryDeleteShell(typeid(QIconDragEvent));
}

// emitting Virtual overrides (virtualFunctions)
// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
// emitting (writeConstructors)
// new QIconDragEvent()
void __qt_construct_QIconDragEvent(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QIconDragEvent()")
    Q_UNUSED(__java_arguments)
    QIconDragEvent *__qt_this = new(__qtjambi_ptr) QIconDragEvent_shell();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// QIconDragEvent::QIconDragEvent()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QIconDragEvent_initialize_1native__Lio_qt_gui_QIconDragEvent_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QIconDragEvent::QIconDragEvent()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QIconDragEvent, sizeof(QIconDragEvent_shell), typeid(QIconDragEvent), true, &deleter_QIconDragEvent, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QIconDragEvent(QIconDragEvent)
void __qt_construct_QIconDragEvent_cref_QIconDragEvent(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QIconDragEvent(QIconDragEvent)")
    jobject other0 = __java_arguments[0].l;
    const QIconDragEvent& __qt_other0 = qtjambi_cast<const QIconDragEvent& >(__jni_env, other0);
    QIconDragEvent *__qt_this = new(__qtjambi_ptr) QIconDragEvent_shell(__qt_other0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QIconDragEvent::QIconDragEvent(QIconDragEvent)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QIconDragEvent_initialize_1native__Lio_qt_gui_QIconDragEvent_2Lio_qt_gui_QIconDragEvent_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QIconDragEvent::QIconDragEvent(QIconDragEvent)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QIconDragEvent_cref_QIconDragEvent, sizeof(QIconDragEvent_shell), typeid(QIconDragEvent), true, &deleter_QIconDragEvent, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QIconDragEvent_shell
void __qt_destruct_QIconDragEvent(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QIconDragEvent")
    reinterpret_cast<QIconDragEvent_shell*>(ptr)->~QIconDragEvent_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QIconDragEvent_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QIconDragEvent *__qt_this = QtJambiAPI::objectFromNativeId<QIconDragEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QIconDragEvent(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QIconDragEvent>("QIconDragEvent", "io/qt/gui/QIconDragEvent");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QIconDragEvent, {
        ConstructorInfo(&__qt_construct_QIconDragEvent, nullptr)
       ,ConstructorInfo(&__qt_construct_QIconDragEvent_cref_QIconDragEvent, "Lio/qt/gui/QIconDragEvent;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QIconDragEvent);
    registerMetaType<QIconDragEvent>("QIconDragEvent");
    registerSizeOfShell(typeId, sizeof(QIconDragEvent_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerDefaultPolymorphyHandler<QEvent, QIconDragEvent>();
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
